@@ -2,4 +2,6 @@ AGENTMAKE_CONFIG = {
     "print_on_terminal": False,
     "word_wrap": False,
 }
-OLLAMA_NOT_FOUND = "`Ollama` is not found! BibleMate AI uses `Ollama` to generate embeddings for semantic searches. You may install it from https://ollama.com/ so that you can perform semantic searches of the Bible with BibleMate AI."
\ No newline at end of file
+OLLAMA_NOT_FOUND = "`Ollama` is not found! BibleMate AI uses `Ollama` to generate embeddings for semantic searches. You may install it from https://ollama.com/ so that you can perform semantic searches of the Bible with BibleMate AI."
+def fix_string(content):
+    return content.replace(" ", " ").replace("‑", "-")
\ No newline at end of file
