@@ -47,7 +47,8 @@ if os.path.isfile(user_bible) and os.path.getsize(user_bible) < 380000000:
 # AI backend
 parser = argparse.ArgumentParser(description = """BibleMate AI CLI options""")
 parser.add_argument("-b", "--backend", action="store", dest="backend", help="AI backend; overrides the default backend temporarily.")
-parser.add_argument("-mcp", "--mcp", action="store", dest="mcp", help=f"specify a custom MCP server to use, e.g. 'http://127.0.0.1:{config.mcp_port}/mcp/'")
+parser.add_argument("-mcp", "--mcp", action="store", dest="mcp", help=f"specify a custom MCP server to use, e.g. 'http://127.0.0.1:{config.mcp_port}/mcp/'; applicable to command `biblemate` only")
+parser.add_argument("-p", "--port", action="store", dest="port", help=f"specify a port for the MCP server to use, e.g. {config.mcp_port}; applicable to command `biblematemcp` only")
 args = parser.parse_args()
 # write to the `config.py` file temporarily for the MCP server to pick it up
 if args.backend:
@@ -60,19 +61,11 @@ else:
     config.backend = DEFAULT_AI_BACKEND
 AGENTMAKE_CONFIG["backend"] = config.backend
 
-# The client that interacts with the Bible Study MCP server
-if args.mcp:
-    client = Client(args.mcp)
-else:
-    builtin_mcp_server = os.path.join(os.path.dirname(os.path.realpath(__file__)), "bible_study_mcp.py")
-    user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py") # The user path has the same basename as the built-in one; users may copy the built-in server settings to this location for customization. 
-    client = Client(user_mcp_server if os.path.isfile(user_mcp_server) else builtin_mcp_server)
-
 def mcp():
     builtin_mcp_server = os.path.join(os.path.dirname(os.path.realpath(__file__)), "bible_study_mcp.py")
-    user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py")
+    user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py") # The user path has the same basename as the built-in one; users may copy the built-in server settings to this location for customization. 
     mcp_script = readTextFile(user_mcp_server if os.path.isfile(user_mcp_server) else builtin_mcp_server)
-    mcp_script = mcp_script.replace("mcp.run(show_banner=False)", f'''mcp.run(show_banner=False, transport="http", port={config.mcp_port})''')
+    mcp_script = mcp_script.replace("mcp.run(show_banner=False)", f'''mcp.run(show_banner=False, transport="http", port={args.port if args.port else config.mcp_port})''')
     exec(mcp_script)
 
 def main():
@@ -173,11 +166,21 @@ hide_tools_order={config.hide_tools_order}
 default_bible="{config.default_bible}"
 max_semantic_matches={config.max_semantic_matches}
 max_log_lines={config.max_log_lines}
+mcp_port={config.mcp_port}
 disabled_tools={pprint.pformat(config.disabled_tools)}"""
     writeTextFile(config_file, configurations)
 
 async def main_async():
 
+    # The client that interacts with the Bible Study MCP server
+    if args.mcp:
+        mcp_server = f"http://127.0.0.1:{config.mcp_port}/mcp/" if args.mcp == "biblemate" else args.mcp
+        client = Client(mcp_server)
+    else:
+        builtin_mcp_server = os.path.join(os.path.dirname(os.path.realpath(__file__)), "bible_study_mcp.py")
+        user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py") # The user path has the same basename as the built-in one; users may copy the built-in server settings to this location for customization. 
+        client = Client(user_mcp_server if os.path.isfile(user_mcp_server) else builtin_mcp_server)
+
     APP_START = True
     DEFAULT_SYSTEM = "You are BibleMate AI, an autonomous agent designed to assist users with their Bible study."
     DEFAULT_MESSAGES = [{"role": "system", "content": DEFAULT_SYSTEM}, {"role": "user", "content": "Hello!"}, {"role": "assistant", "content": "Hello! I'm BibleMate AI, your personal assistant for Bible study. How can I help you today?"}] # set a tone for bible study; it is userful when auto system is used.
